
from os.path import join
import sys
import os
import random
try:
    import configparser
except ImportError:
    # Python 2.x fallback
    import ConfigParser as configparser



def esm_ensemble_init(exp_id):

   # 1 - load ensemble config file
   print("Initialization for experiment " + str(exp_id))
   config = configparser.ConfigParser()
   config.read(os.path.join(os.path.dirname(__file__), 'config', 'esm_ensemble.conf'))
   # 2 - create folders for the topdir and each ensemble member runtime folder
   if config.has_option('common', 'top_working_dir'):
      top_dir = config['common']['top_working_dir']
      output_dir = config['common']['output_dir']
      # define the access rights - readable and accessible by all users, and write access by only the owner
      access_rights = 0o755
      try:
         # top dir
         if not os.path.exists(top_dir):
            os.makedirs(top_dir , access_rights)

         # output dir
         if not os.path.exists(output_dir):
            os.makedirs(output_dir, access_rights)

         # get list of members
         sdates_list = (config['common']['ensemble_start_dates']).split()
         print("Creating directories for the following list of dates: " + str(sdates_list))
         for sdate in sdates_list:
            print(sdate)
            if not os.path.exists(top_dir + "/" + sdate):
               os.mkdir(top_dir + "/" + sdate, access_rights)

            if not os.path.exists(output_dir + "/" + sdate):
               os.mkdir(output_dir + "/" + sdate, access_rights)

            #TODO: create function to process the namelist templates passing the config
            #create symlink for FESOM2 executable for each working dir
            fesom_exe = config['fesom2']['fesom_binary_path']
            os.symlink( fesom_exe , top_dir + "/" + sdate + "/fesom_x" )


      except OSError as exc:  # Python ≥ 2.5
          print("Initialization failed :" + exc.strerror )
          raise
   else:
      print("ERROR - topdir undefined path not found")

# for testing purposes
if __name__ == "__main__":
   print("Running FESOM2 INIT" )
   # first parameter: number of ensemble members
   # 0 - create a ramdon nr for the experiment id
   exp_id = random.randint(100000, 999999)
   esm_ensemble_init(exp_id)
   print("############ All experiment folders created successfully ################")
